==> horizon-20.1.0.tar.gz: horizon-20.1.0/openstack_dashboard/static/app/core/network_qos/actions/actions.module.spec.js <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

(function() {
  'use strict';

  describe('network_qos actions module', function() {
    var registry;
    beforeEach(module('horizon.app.core.network_qos.actions'));

    beforeEach(inject(function($injector) {
      registry = $injector.get('horizon.framework.conf.resource-type-registry.service');
    }));

    it('registers Create Policy as a global action', function() {
      var actions = registry.getResourceType('OS::Neutron::QoSPolicy').globalActions;
      expect(actionHasId(actions, 'createPolicyAction')).toBe(true);
    });

    it('registers Delete Policy as an item action', function() {
      var actions = registry.getResourceType('OS::Neutron::QoSPolicy').itemActions;
      expect(actionHasId(actions, 'deletePolicyAction')).toBe(true);
    });

    it('registers Delete Policies as a batch action', function() {
      var actions = registry.getResourceType('OS::Neutron::QoSPolicy').batchActions;
      expect(actionHasId(actions, 'batchDeletePolicyAction')).toBe(true);
    });

    function actionHasId(list, value) {
      return list.filter(matchesId).length === 1;

      function matchesId(action) {
        return action.id === value;
      }
    }

  });

})();

==> horizon_25.5.1.orig.tar.gz: horizon-25.5.1/openstack_dashboard/static/app/core/network_qos/actions/actions.module.spec.js <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

(function() {
  'use strict';

  describe('network_qos actions module', function() {
    var registry;
    beforeEach(module('horizon.app.core.network_qos.actions'));

    beforeEach(inject(function($injector) {
      registry = $injector.get('horizon.framework.conf.resource-type-registry.service');
    }));

    it('registers Create Policy as a global action', function() {
      var actions = registry.getResourceType('OS::Neutron::QoSPolicy').globalActions;
      expect(actionHasId(actions, 'createPolicyAction')).toBe(true);
    });

    it('registers Create Rule as a global action', function() {
      var actions = registry.getResourceType('OS::Neutron::QoSPolicy').itemActions;
      expect(actionHasId(actions, 'addRulePolicyAction')).toBe(true);
    });

    it('registers Edit Rule as a global action', function() {
      var actions = registry.getResourceType('OS::Neutron::QoSPolicy').itemActions;
      expect(actionHasId(actions, 'editRuleAction')).toBe(true);
    });

    it('registers Delete Rule as a global action', function() {
      var actions = registry.getResourceType('OS::Neutron::QoSPolicy').itemActions;
      expect(actionHasId(actions, 'deleteRuleAction')).toBe(true);
    });

    it('registers Delete Policy as an item action', function() {
      var actions = registry.getResourceType('OS::Neutron::QoSPolicy').itemActions;
      expect(actionHasId(actions, 'deletePolicyAction')).toBe(true);
    });

    it('registers Delete Policies as a batch action', function() {
      var actions = registry.getResourceType('OS::Neutron::QoSPolicy').batchActions;
      expect(actionHasId(actions, 'batchDeletePolicyAction')).toBe(true);
    });

    function actionHasId(list, value) {
      return list.filter(matchesId).length === 1;

      function matchesId(action) {
        return action.id === value;
      }
    }

  });

})();
